@@ -9,24 +9,29 @@
 #' provides group identifiers for the nodes to be added.
 #' @param label an optional character object that
 #' describes the nodes to be added.
+#' @param ... optional node attributes supplied as
+#' vectors.
 #' @return a graph object of class \code{dgr_graph}.
 #' @examples
 #' # Create an empty graph and add 5 nodes; these
 #' # nodes will be assigned ID values from `1` to `5`
 #' graph <-
 #'   create_graph() %>%
-#'   add_n_nodes(5)
+#'   add_n_nodes(n = 5)
 #'
 #' # Get the graph's nodes
-#' graph %>% get_node_ids()
+#' graph %>%
+#'   get_node_ids()
 #' #> [1] 1 2 3 4 5
-#' @importFrom dplyr bind_rows
+#' @importFrom dplyr select bind_cols bind_rows
+#' @importFrom tibble as_tibble
 #' @export add_n_nodes
 
 add_n_nodes <- function(graph,
                         n,
                         type = NULL,
-                        label = NULL) {
+                        label = NULL,
+                        ...) {
 
   # Get the time of function start
   time_function_start <- Sys.time()
@@ -44,6 +49,32 @@ add_n_nodes <- function(graph,
     label <- as.character(NA)
   }
 
+  # Create bindings for specific variables
+  id <- index__ <- NULL
+
+  # Collect extra vectors of data as `extras`
+  extras <- list(...)
+
+  if (length(extras) > 0) {
+
+    extras_tbl <- tibble::as_tibble(extras)
+
+    if (nrow(extras_tbl) < n) {
+
+      extras$index__ <- 1:n
+
+      extras_tbl <-
+        tibble::as_tibble(extras) %>%
+        dplyr::select(-index__)
+    }
+
+    if ("id" %in% colnames(extras_tbl)) {
+      extras_tbl <-
+        extras_tbl %>%
+        dplyr::select(-id)
+    }
+  }
+
   # Create a ndf of the correct length
   new_nodes <-
     create_node_df(
@@ -51,6 +82,14 @@ add_n_nodes <- function(graph,
       type = type,
       label = label)
 
+  # Add extra columns if available
+  if (exists("extras_tbl")) {
+
+    new_nodes <-
+      new_nodes %>%
+      dplyr::bind_cols(extras_tbl)
+  }
+
   new_nodes[, 1] <- new_nodes[, 1] + graph$last_node
 
   graph$nodes_df <-
@@ -70,10 +109,17 @@ add_n_nodes <- function(graph,
       nodes = nrow(graph$nodes_df),
       edges = nrow(graph$edges_df))
 
+  # Perform graph actions, if any are available
+  if (nrow(graph$graph_actions) > 0) {
+    graph <-
+      graph %>%
+      trigger_graph_actions()
+  }
+
   # Write graph backup if the option is set
   if (graph$graph_info$write_backups) {
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
