@@ -7,6 +7,7 @@
 #' \code{dgr_graph}.
 #' @param edge_attr the edge attribute from which to
 #' obtain values.
+#' @param name an optional name for the cached vector.
 #' @param mode a option to recast the returned vector
 #' of edge attribute value as \code{numeric} or
 #' \code{character}.
@@ -17,33 +18,42 @@
 #' the edge is incoming for filtering the list of
 #' edges present in the graph.
 #' @return a graph object of class \code{dgr_graph}.
+#' @examples
 #' # Set a seed
-#' set.seed(25)
+#' set.seed(23)
 #'
 #' # Create a graph with 10 nodes and 9 edges
 #' graph <-
 #'   create_graph() %>%
-#'   add_n_nodes(10) %>%
+#'   add_n_nodes(n = 10) %>%
 #'   add_edges_w_string(
-#'     "1->2 1->3 2->4 2->5 3->6 3->7
-#'      4->8 4->9 5->10") %>%
+#'     edges =
+#'       "1->2 1->3 2->4 2->5 3->6
+#'        3->7 4->8 4->9 5->10") %>%
 #'   set_edge_attrs(
-#'     "value", rnorm(edge_count(.), 5, 2))
+#'     edge_attr = "value",
+#'     values = rnorm(edge_count(.), 5, 2))
 #'
-#' # Cache all values from the edge attribute `value`
-#' # as a numeric vector
+#' # Cache all values from the edge attribute
+#' # `value` as a numeric vector
 #' graph <-
 #'   graph %>%
-#'   cache_edge_attrs("value", "numeric")
+#'   cache_edge_attrs(
+#'     edge_attr = value,
+#'     name = "edge_value")
 #'
 #' # Get the mean from all values available in
 #' # the cache
-#' graph %>% get_cache() %>% mean()
-#' #> [1] 4.62536
+#' graph %>%
+#'   get_cache(name = "edge_value") %>%
+#'   mean()
+#' #> [1] 5.744332
+#' @importFrom rlang enquo UQ
 #' @export cache_edge_attrs
 
 cache_edge_attrs <- function(graph,
                              edge_attr,
+                             name = NULL,
                              mode = NULL,
                              from = NULL,
                              to = NULL) {
@@ -51,6 +61,9 @@ cache_edge_attrs <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  edge_attr <- rlang::enquo(edge_attr)
+  edge_attr <- (rlang::UQ(edge_attr) %>% paste())[2]
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
     stop("The graph object is not valid.")
@@ -74,11 +87,11 @@ cache_edge_attrs <- function(graph,
   }
 
   if (any(edge_attr %in%
-          colnames(edges_df)[-c(1:2)])) {
+          colnames(edges_df)[-c(1:3)])) {
 
     edges_attr_vector <-
       edges_df[, which(colnames(edges_df) %in%
-                        edge_attr)]
+                         edge_attr)]
 
     if (!is.null(mode)) {
       if (mode == "numeric") {
@@ -95,8 +108,19 @@ cache_edge_attrs <- function(graph,
     }
   }
 
-  # Cache vector of edge attributes in the graph
-  graph$cache <- edges_attr_vector
+  # Cache vector of edge attributes in the
+  # graph's `cache` list object
+  if (!is.null(name)) {
+    graph$cache[[name]] <- edges_attr_vector
+  } else {
+    if (length(graph$cache) == 0) {
+      graph$cache[[1]] <- edges_attr_vector
+      names(graph$cache) <- 1
+    } else {
+      graph$cache[[(length(graph$cache) + 1)]] <-
+        edges_attr_vector
+    }
+  }
 
   # Update the `graph_log` df with an action
   graph$graph_log <-
@@ -114,5 +138,5 @@ cache_edge_attrs <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
