@@ -31,33 +31,43 @@
 #' @return a graph object of class
 #' \code{dgr_graph}.
 #' @examples
-#' # Create a graph with 5 nodes and 4 edges
+#' # Create a graph with 5
+#' # nodes and 4 edges
 #' graph <-
 #'   create_graph() %>%
-#'   add_path(5) %>%
+#'   add_path(n = 5) %>%
 #'   set_edge_attrs(
-#'     "weight", c(3.7, 6.3, 9.2, 1.6))
+#'     edge_attr = weight,
+#'     values = c(3.7, 6.3, 9.2, 1.6))
 #'
-#' # We can bucketize values in the edge `weight`
-#' # attribute using `cut_points` and, by doing so,
-#' # assign colors to each of the bucketed ranges
-#' # (for values not part of any bucket, a gray color
+#' # We can bucketize values in
+#' # the edge `weight` attribute using
+#' # `cut_points` and, by doing so,
+#' # assign colors to each of the
+#' # bucketed ranges (for values not
+#' # part of any bucket, a gray color
 #' # is assigned by default)
 #' graph <-
 #'   graph %>%
 #'   colorize_edge_attrs(
-#'     "weight", "color",
-#'     cut_points = c(0, 2, 4, 6, 8, 10))
+#'     edge_attr_from = weight,
+#'     edge_attr_to = color,
+#'     cut_points = c(0, 2, 4, 6, 8, 10),
+#'     palette = "RdYlGn")
 #'
-#' # Now there will be a `color` edge attribute
-#' # with distinct colors
+#' # Now there will be a `color`
+#' # edge attribute with distinct
+#' # colors (from the RColorBrewer
+#' # Red-Yellow-Green palette)
 #' get_edge_df(graph)
 #' #>   id from to  rel weight   color
 #' #> 1  1    1  2 <NA>    3.7 #FDAE61
-#' #> 2  2    2  3 <NA>    6.3 #ABDDA4
-#' #> 3  3    3  4 <NA>    9.2 #2B83BA
+#' #> 2  2    2  3 <NA>    6.3 #A6D96A
+#' #> 3  3    3  4 <NA>    9.2 #1A9641
 #' #> 4  4    4  5 <NA>    1.6 #D7191C
-#' @import viridis RColorBrewer
+#' @import RColorBrewer
+#' @importFrom viridis viridis
+#' @importFrom rlang enquo UQ
 #' @export colorize_edge_attrs
 
 colorize_edge_attrs <- function(graph,
@@ -72,15 +82,17 @@ colorize_edge_attrs <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  edge_attr_from <- rlang::enquo(edge_attr_from)
+  edge_attr_from <- (rlang::UQ(edge_attr_from) %>% paste())[2]
+
+  edge_attr_to <- rlang::enquo(edge_attr_to)
+  edge_attr_to <- (rlang::UQ(edge_attr_to) %>% paste())[2]
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
     stop("The graph object is not valid.")
   }
 
-  # Get the number of nodes ever created for
-  # this graph
-  nodes_created <- graph$last_node
-
   # Extract edf from graph
   edges_df <- graph$edges_df
 
@@ -125,7 +137,7 @@ colorize_edge_attrs <- function(graph,
     }
   }
 
-  # Reverse color palette if `reverse_palette = TRUE``
+  # Reverse color palette if `reverse_palette = TRUE`
   if (reverse_palette == TRUE) {
     color_palette <- rev(color_palette)
   }
@@ -201,8 +213,21 @@ colorize_edge_attrs <- function(graph,
     }
   }
 
-  # Modify the graph
-  graph$edges_df <- edges_df
+  # Get the finalized column of values
+  edges_attr_vector_colorized <- edges_df[, ncol(edges_df)]
+
+  edge_attr_to_2 <- rlang::enquo(edge_attr_to)
+
+  # Set the edge attribute values for nodes specified
+  # in selection
+  graph <-
+    set_edge_attrs(
+      x = graph,
+      edge_attr = rlang::UQ(edge_attr_to_2),
+      values = edges_attr_vector_colorized)
+
+  # Remove last action from the `graph_log`
+  graph$graph_log <- graph$graph_log[1:(nrow(graph$graph_log) - 1), ]
 
   # Update the `graph_log` df with an action
   graph$graph_log <-
@@ -220,5 +245,5 @@ colorize_edge_attrs <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
