@@ -7,6 +7,8 @@
 #' random graph.
 #' @param directed an option for whether the random
 #' graph should be undirected (default) or directed.
+#' @param graph_name an optional string for labeling
+#' the graph object.
 #' @param display_labels display node labels.
 #' @param set_seed supplying a value sets a random seed
 #' of the \code{Mersenne-Twister} implementation.
@@ -21,8 +23,7 @@
 #' # and 75 edges
 #' random_graph_directed <-
 #'   create_random_graph(
-#'     n = 50,
-#'     m = 75)
+#'     n = 50, m = 75)
 #' @importFrom utils combn
 #' @importFrom tibble as_tibble
 #' @importFrom dplyr rename sample_n mutate select_
@@ -31,6 +32,7 @@
 create_random_graph <- function(n,
                                 m,
                                 directed = TRUE,
+                                graph_name = NULL,
                                 display_labels = TRUE,
                                 set_seed = NULL,
                                 write_backups = FALSE) {
@@ -82,6 +84,7 @@ create_random_graph <- function(n,
         nodes_df = ndf,
         edges_df = edf,
         directed = ifelse(directed, TRUE, FALSE),
+        graph_name = graph_name,
         write_backups = write_backups)
 
   } else {
@@ -91,11 +94,12 @@ create_random_graph <- function(n,
       create_graph(
         nodes_df = ndf,
         directed = ifelse(directed, TRUE, FALSE),
+        graph_name = graph_name,
         write_backups = write_backups)
   }
 
   # Modify the `function_used` in the `graph_log` df
   graph$graph_log$function_used[1] <- "create_random_graph"
 
-  return(graph)
+  graph
 }
