@@ -10,38 +10,43 @@
 #' @examples
 #' # This graph, created using `create_random_graph()`
 #' # is almost fully connected but there is an
-#' # isolated node (`13`) with no edges
+#' # isolated node (`8`) with no edges
 #' graph_1 <-
 #'   create_random_graph(
-#'     30, 50, set_seed = 1)
+#'     n = 30, m = 40,
+#'     set_seed = 23)
 #'
-#' # There won't be any connected nodes to `13` so when
-#' # specifying this isolated node with
-#' # `get_all_connected_nodes()` will return NA
-#' graph_1 %>% get_all_connected_nodes(13)
+#' # There won't be any connected nodes to `8`
+#' # so when specifying this node with
+#' # `get_all_connected_nodes()` we get NA back
+#' graph_1 %>%
+#'   get_all_connected_nodes(node = 8)
 #' #> [1] NA
 #'
 #' # Any other node in `graph_1` will provide a vector
-#' # of all the nodes other than `13`
-#' graph_1 %>% get_all_connected_nodes(2)
-#' #>  [1]  1  3  4  5  6  7  8  9 10 11 12 14 15 16 17
+#' # of all the nodes other than `8`
+#' graph_1 %>%
+#'   get_all_connected_nodes(node = 1)
+#' #>  [1]  2  3  4  5  6  7  9 10 11 12 13 14 15 16 17
 #' #> [16] 18 19 20 21 22 23 24 25 26 27 28 29 30
 #'
 #' # The following graph has two clusters of nodes
 #' # (i.e., the graph has two connected components)
 #' graph_2 <-
 #'   create_graph() %>%
-#'   add_path(6) %>%
-#'   add_path(4)
+#'   add_path(n = 6) %>%
+#'   add_path(n = 4)
 #'
 #' # In `graph_2`, node `1` is in the larger of the two
 #' # connected components
-#' graph_2 %>% get_all_connected_nodes(1)
+#' graph_2 %>%
+#'   get_all_connected_nodes(node = 1)
 #' #> [1] 2 3 4 5 6
 #'
 #' # Also in `graph_2`, node `8` is in the smaller of
 #' # the two connected components
-#' graph_2 %>% get_all_connected_nodes(8)
+#' graph_2 %>%
+#'   get_all_connected_nodes(node = 8)
 #' #> [1]  7  9 10
 #' @importFrom dplyr filter
 #' @export get_all_connected_nodes
@@ -59,7 +64,7 @@ get_all_connected_nodes <- function(graph,
 
   # Verify that the node ID provided is in the graph
   if (!(node %in% get_node_ids(graph))) {
-    stop("The node ID provided is not in the graph")
+    stop("The node ID provided is not in the graph.")
   }
 
   # Get a data frame of the weakly-connected
@@ -93,5 +98,5 @@ get_all_connected_nodes <- function(graph,
     connected_nodes <- NA
   }
 
-  return(connected_nodes)
+  connected_nodes
 }
