@@ -14,28 +14,44 @@
 #' # Create a random graph
 #' graph <-
 #'   create_random_graph(
-#'     10, 22, set_seed = 1)
+#'     n = 10, m = 22,
+#'     set_seed = 23)
 #'
-#' # Get closeness values for all nodes in the graph
+#' # Get closeness values for all nodes
+#' # in the graph
 #' get_closeness(graph)
 #' #>    id  closeness
 #' #> 1   1 0.07142857
-#' #> 2   2 0.07692308
-#' #> 3   3 0.06666667
-#' #> 4   4 0.07142857
-#' #> 5   5 0.08333333
-#' #> 6   6 0.05882353
-#' #> 7   7 0.08333333
-#' #> 8   8 0.07692308
-#' #> 9   9 0.06666667
-#' #> 10 10 0.05882353
+#' #> 2   2 0.07142857
+#' #> 3   3 0.07142857
+#' #> 4   4 0.06250000
+#' #> 5   5 0.07692308
+#' #> 6   6 0.09090909
+#' #> 7   7 0.06666667
+#' #> 8   8 0.05882353
+#' #> 9   9 0.07692308
+#' #> 10 10 0.07692308
 #'
 #' # Add the closeness values to the graph
 #' # as a node attribute
 #' graph <-
 #'   graph %>%
 #'   join_node_attrs(
-#'     get_closeness(.))
+#'     df = get_closeness(.))
+#'
+#' # Display the graph's node data frame
+#' get_node_df(graph)
+#' #>    id type label value  closeness
+#' #> 1   1 <NA>     1   6.0 0.07142857
+#' #> 2   2 <NA>     2   2.5 0.07142857
+#' #> 3   3 <NA>     3   3.5 0.07142857
+#' #> 4   4 <NA>     4   7.5 0.06250000
+#' #> 5   5 <NA>     5   8.5 0.07692308
+#' #> 6   6 <NA>     6   4.5 0.09090909
+#' #> 7   7 <NA>     7  10.0 0.06666667
+#' #> 8   8 <NA>     8  10.0 0.05882353
+#' #> 9   9 <NA>     9   8.5 0.07692308
+#' #> 10 10 <NA>    10  10.0 0.07692308
 #' @importFrom igraph closeness
 #' @export get_closeness
 
@@ -47,6 +63,13 @@ get_closeness <- function(graph,
     stop("The graph object is not valid.")
   }
 
+  # Ensure that values provided for the
+  # `direction` argument are from the
+  # valid options
+  if (!(direction %in% c("all", "in", "out"))) {
+    stop("Valid options for `direction` are `all`, `in`, or `out`.")
+  }
+
   # Convert the graph to an igraph object
   ig_graph <- to_igraph(graph)
 
@@ -68,10 +91,10 @@ get_closeness <- function(graph,
   }
 
   # Create df with betweenness scores
-  closeness_values_df <-
-    data.frame(id = names(closeness_values),
-               closeness = closeness_values,
-               stringsAsFactors = FALSE)
-
-  return(closeness_values_df)
+  data.frame(
+    id = closeness_values %>%
+      names() %>%
+      as.integer(),
+    closeness = closeness_values,
+    stringsAsFactors = FALSE)
 }
