@@ -8,23 +8,32 @@
 #' # Create a graph using several piped functions
 #' graph <-
 #'   create_graph() %>%
-#'   add_n_nodes(1, "a") %>%
-#'   select_last_node %>%
-#'   add_n_nodes_ws(5, "from", "b") %>%
-#'   select_edges_by_node_id(3:5) %>%
+#'   add_n_nodes(
+#'     n = 1,
+#'     type = "a") %>%
+#'   select_last_nodes_created() %>%
+#'   add_n_nodes_ws(
+#'     n = 5,
+#'     direction = "from",
+#'     type = "b") %>%
+#'   select_edges_by_node_id(nodes = 3:5) %>%
 #'   set_edge_attrs_ws(
-#'     "color", "green") %>%
+#'     edge_attr = color,
+#'     value = "green") %>%
 #'   set_edge_attrs_ws(
-#'     "rel", "a") %>%
+#'     edge_attr = rel,
+#'     value = "a") %>%
 #'   invert_selection %>%
 #'   set_edge_attrs_ws(
-#'     "color", "blue") %>%
+#'     edge_attr = color,
+#'     value = "blue") %>%
 #'   set_edge_attrs_ws(
-#'     "rel", "b") %>%
+#'     edge_attr = rel,
+#'     value = "b") %>%
 #'   clear_selection()
 #'
 #' # Get the graph's internal edge data frame (edf)
-#' graph %>% get_edge_df()
+#' get_edge_df(graph)
 #' #>   id from to rel color
 #' #> 1  1    1  2   b  blue
 #' #> 2  2    1  3   a green
@@ -40,5 +49,5 @@ get_edge_df <- function(graph) {
     stop("The graph object is not valid.")
   }
 
-  return(graph$edges_df)
+  graph$edges_df
 }
