@@ -1,8 +1,8 @@
 #' Get all nodes associated with connected components
 #' @description Determine which nodes in a graph belong
-#' to different connected components (i.e., distinct
-#' sets of nodes with traversable paths to and from
-#' each node in the set).
+#' to different weakly connected components (i.e.,
+#' distinct sets of nodes with traversable paths to and
+#' from each node in the set).
 #' @param graph a graph object of class
 #' \code{dgr_graph}.
 #' @return a data frame with nodes and their membership
@@ -11,8 +11,8 @@
 #' # Create a graph with 2 cycles
 #' graph <-
 #'   create_graph() %>%
-#'   add_cycle(4) %>%
-#'   add_cycle(3)
+#'   add_cycle(n = 4) %>%
+#'   add_cycle(n = 3)
 #'
 #' # Check if the graph is connected
 #' is_graph_connected(graph)
@@ -47,11 +47,8 @@ get_w_connected_cmpts <- function(graph) {
     igraph::components(ig_graph, "weak")
 
   # Create the output data frame
-  components_df <-
-    data.frame(
-      id = as.integer(names(components$membership)),
-      wc_component = components$membership,
-      stringsAsFactors = FALSE)
-
-  return(components_df)
+  data.frame(
+    id = as.integer(names(components$membership)),
+    wc_component = components$membership,
+    stringsAsFactors = FALSE)
 }
