@@ -6,8 +6,6 @@
 #' @param graph a graph object of class
 #' \code{dgr_graph}.
 #' @param df the data frame to use for joining.
-#' \code{dgr_graph} that is created using
-#' \code{create_graph}.
 #' @param by_graph optional specification of the column
 #' in the graph's internal edge data frame for the left
 #' join. If both \code{by_graph} and \code{by_df} are
@@ -22,17 +20,19 @@
 #' @return a graph object of class
 #' \code{dgr_graph}.
 #' @examples
+#' # Set a seed
+#' set.seed(23)
+#'
 #' # Create a simple graph
 #' graph <-
 #'   create_graph() %>%
-#'   add_n_nodes(5) %>%
-#'   add_edges_w_string("1->2 1->3 2->4 2->5 3->5")
+#'   add_n_nodes(n = 5) %>%
+#'   add_edges_w_string(
+#'     edges = "1->2 1->3 2->4 2->5 3->5")
 #'
 #' # Create a data frame with node ID values
 #' # representing the graph edges (with `from` and `to`
 #' # columns), and, a set of numeric values
-#' set.seed(25)
-#'
 #' df <-
 #'   data.frame(
 #'     from = c(1, 1, 2, 2, 3),
@@ -43,17 +43,20 @@
 #' # graph's edges; this works as a left join using
 #' # identically-named columns in the graph and the df
 #' # (in this case `from` and `to` are common to both)
-#' graph <- graph %>% join_edge_attrs(df)
+#' graph <-
+#'   graph %>%
+#'   join_edge_attrs(
+#'     df = df)
 #'
 #' # Get the graph's internal edf to show that the
 #' # join has been made
 #' get_edge_df(graph)
 #' #>   id from to  rel   values
-#' #> 1  1    1  2 <NA> 4.788166
-#' #> 2  2    1  3 <NA> 3.958409
-#' #> 3  3    2  4 <NA> 3.846692
-#' #> 4  4    2  5 <NA> 5.321531
-#' #> 5  5    3  5 <NA> 3.499870
+#' #> 1  1    1  2 <NA> 5.996605
+#' #> 2  2    1  3 <NA> 6.107490
+#' #> 3  3    2  4 <NA> 4.721914
+#' #> 4  4    2  5 <NA> 6.019205
+#' #> 5  5    3  5 <NA> 5.045437
 #' @importFrom dplyr select everything
 #' @export join_edge_attrs
 
@@ -131,5 +134,5 @@ join_edge_attrs <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
