@@ -7,7 +7,7 @@
 #' Selections of nodes can be performed using
 #' the following \code{select_...} functions:
 #' \code{select_nodes()},
-#' \code{select_last_node()},
+#' \code{select_last_nodes_created()},
 #' \code{select_nodes_by_degree()},
 #' \code{select_nodes_by_id()}, or
 #' \code{select_nodes_in_neighborhood()}.
@@ -27,16 +27,19 @@
 #' # Create a simple graph
 #' graph <-
 #'   create_graph() %>%
-#'   add_path(6)
+#'   add_path(n = 6)
 #'
 #' # Select specific nodes from the graph and
 #' # apply the node attribute `color = blue` to
 #' # those selected nodes
 #' graph <-
 #'   graph %>%
-#'   select_nodes_by_id(1:4) %>%
+#'   select_nodes_by_id(
+#'     nodes = 1:4) %>%
 #'   trav_out() %>%
-#'   set_node_attrs_ws("color", "blue")
+#'   set_node_attrs_ws(
+#'     node_attr = color,
+#'     value = "blue")
 #'
 #' # Show the internal node data frame to verify
 #' # that the node attribute has been set for
@@ -49,6 +52,7 @@
 #' #> 4  4 <NA>     4  blue
 #' #> 5  5 <NA>     5  blue
 #' #> 6  6 <NA>     6  <NA>
+#' @importFrom rlang enquo UQ
 #' @export set_node_attrs_ws
 
 set_node_attrs_ws <- function(graph,
@@ -58,6 +62,9 @@ set_node_attrs_ws <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  node_attr <- rlang::enquo(node_attr)
+  node_attr <- (rlang::UQ(node_attr) %>% paste())[2]
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
     stop("The graph object is not valid.")
@@ -76,19 +83,21 @@ set_node_attrs_ws <- function(graph,
   # Get vector of node ID values
   nodes <- graph$node_selection$node
 
+  node_attr_2 <- rlang::enquo(node_attr)
+
   # Call the `set_node_attrs()` function
   # and update the graph
   graph <-
     set_node_attrs(
       x = graph,
-      node_attr = node_attr,
+      node_attr = rlang::UQ(node_attr_2),
       values = value,
       nodes = nodes)
 
   # Update the `graph_log` df with an action
   graph$graph_log <-
+    graph$graph_log[-nrow(graph$graph_log),] %>%
     add_action_to_log(
-      graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
       function_used = "set_node_attrs_ws",
       time_modified = time_function_start,
@@ -101,5 +110,5 @@ set_node_attrs_ws <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
