@@ -32,13 +32,15 @@
 #' graph <-
 #'   create_graph() %>%
 #'   add_n_nodes(
-#'     2, type = "a",
+#'     n = 2,
+#'     type = "a",
 #'     label = c("asd", "iekd")) %>%
 #'   add_n_nodes(
-#'     3, type = "b",
+#'     n = 3,
+#'     type = "b",
 #'     label = c("idj", "edl", "ohd")) %>%
 #'   add_edges_w_string(
-#'     "1->2 1->3 2->4 2->5 3->5",
+#'     edges = "1->2 1->3 2->4 2->5 3->5",
 #'     rel = c(NA, "A", "B", "C", "D"))
 #'
 #' # Create a data frame with node ID values
@@ -62,9 +64,10 @@
 #' # edge data frame (edf)
 #' graph <-
 #'   graph %>%
-#'   join_edge_attrs(df_edges) %>%
-#'   join_node_attrs(df_nodes)
+#'   join_edge_attrs(df = df_edges) %>%
+#'   join_node_attrs(df = df_nodes)
 #'
+#' # Show the graph's internal node data frame
 #' get_node_df(graph)
 #' #>   id type label values
 #' #> 1  1    a   asd   8.58
@@ -73,6 +76,7 @@
 #' #> 4  4    b   edl   6.71
 #' #> 5  5    b   ohd   7.48
 #'
+#' # Show the graph's internal edge data frame
 #' get_edge_df(graph)
 #' #>   id from to  rel values
 #' #> 1  1    1  2 <NA>   6.00
@@ -85,7 +89,7 @@
 #' # to adjacent nodes with no conditions on
 #' # the nodes traversed to
 #' graph %>%
-#'   select_nodes_by_id(3) %>%
+#'   select_nodes_by_id(nodes = 3) %>%
 #'   trav_both() %>%
 #'   get_selection()
 #' #> [1] 1 5
@@ -95,9 +99,9 @@
 #' # numeric values less than `8.0` for
 #' # the `values` node attribute
 #' graph %>%
-#'   select_nodes_by_id(2) %>%
+#'   select_nodes_by_id(nodes = 2) %>%
 #'   trav_both(
-#'     conditions = "values < 8.0") %>%
+#'     conditions = values < 8.0) %>%
 #'   get_selection()
 #' #> [1] 4 5
 #'
@@ -105,34 +109,32 @@
 #' # nodes, filtering to those nodes that
 #' # have a `type` attribute of `b`
 #' graph %>%
-#'   select_nodes_by_id(5) %>%
+#'   select_nodes_by_id(nodes = 5) %>%
 #'   trav_both(
-#'     conditions = "type == 'b'") %>%
+#'     conditions = type == "b") %>%
 #'   get_selection()
 #' #> [1] 3
 #'
 #' # Traverse from node `2` to any adjacent
 #' # nodes, and use multiple conditions for the
-#' # traversal (using a vector in `conditions`
-#' # creates a set of `AND` conditions)
+#' # traversal
 #' graph %>%
-#'   select_nodes_by_id(2) %>%
+#'   select_nodes_by_id(nodes = 2) %>%
 #'   trav_both(
-#'     conditions = c(
-#'       "type == 'a'",
-#'       "values > 8.0")) %>%
+#'     conditions =
+#'       type == "a" &
+#'       values > 8.0) %>%
 #'   get_selection()
 #' #> [1] 1
 #'
 #' # Traverse from node `2` to any adjacent
 #' # nodes, and use multiple conditions with
-#' # a single-length vector (here, using a
-#' # `|` to create a set of `OR` conditions)
+#' # a single-length vector
 #' graph %>%
-#'   select_nodes_by_id(2) %>%
+#'   select_nodes_by_id(nodes = 2) %>%
 #'   trav_both(
-#'     conditions = c(
-#'       "type == 'a' | values > 8.0")) %>%
+#'     conditions =
+#'       type == "a" | values > 8.0) %>%
 #'   get_selection()
 #' #> [1] 1
 #'
@@ -140,9 +142,9 @@
 #' # nodes, and use a regular expression as
 #' # a filtering condition
 #' graph %>%
-#'   select_nodes_by_id(2) %>%
+#'   select_nodes_by_id(nodes = 2) %>%
 #'   trav_both(
-#'     conditions = "grepl('..d', label)") %>%
+#'     conditions = grepl("..d", label)) %>%
 #'   get_selection()
 #' #> [1] 1 5
 #'
@@ -151,12 +153,15 @@
 #' # nodes
 #' graph <-
 #'   create_graph() %>%
-#'   add_path(5) %>%
-#'   select_nodes_by_id(c(2, 4)) %>%
-#'   set_node_attrs_ws("value", 5)
+#'   add_path(n = 5) %>%
+#'   select_nodes_by_id(nodes = c(2, 4)) %>%
+#'   set_node_attrs_ws(
+#'     node_attr = value,
+#'     value = 5)
 #'
 #' # Show the graph's internal node data frame
-#' graph %>% get_node_df()
+#' graph %>%
+#'   get_node_df()
 #' #>   id type label value
 #' #> 1  1 <NA>     1    NA
 #' #> 2  2 <NA>     2     5
@@ -165,7 +170,8 @@
 #' #> 5  5 <NA>     5    NA
 #'
 #' # Show the graph's internal edge data frame
-#' graph %>% get_edge_df()
+#' graph %>%
+#'   get_edge_df()
 #' #>   id from to  rel
 #' #> 1  1    1  2 <NA>
 #' #> 2  2    2  3 <NA>
@@ -182,12 +188,13 @@
 #' graph <-
 #'   graph %>%
 #'   trav_both(
-#'     copy_attrs_from = "value",
+#'     copy_attrs_from = value,
 #'     agg = "sum")
 #'
 #' # Show the graph's internal node data frame
 #' # after this change
-#' graph %>% get_node_df()
+#' graph %>%
+#'   get_node_df()
 #' #>   id type label value
 #' #> 1  1 <NA>     1     5
 #' #> 2  2 <NA>     2     5
@@ -196,6 +203,7 @@
 #' #> 5  5 <NA>     5     5
 #' @importFrom dplyr filter_ inner_join right_join rename distinct select select_ union_all group_by summarize_ everything
 #' @importFrom tibble as_tibble
+#' @importFrom rlang enquo UQ
 #' @export trav_both
 
 trav_both <- function(graph,
@@ -203,6 +211,15 @@ trav_both <- function(graph,
                       copy_attrs_from = NULL,
                       agg = "sum") {
 
+  conditions <- rlang::enquo(conditions)
+
+  copy_attrs_from <- rlang::enquo(copy_attrs_from)
+  copy_attrs_from <- (rlang::UQ(copy_attrs_from) %>% paste())[2]
+
+  if (copy_attrs_from == "NULL") {
+    copy_attrs_from <- NULL
+  }
+
   # Get the time of function start
   time_function_start <- Sys.time()
 
@@ -262,12 +279,12 @@ trav_both <- function(graph,
   # If traversal conditions are provided then
   # pass in those conditions and filter the
   # data frame of `valid_nodes`
-  if (!is.null(conditions)) {
-    for (i in 1:length(conditions)) {
-      valid_nodes <-
-        valid_nodes %>%
-        dplyr::filter_(conditions[i])
-    }
+  if (!((rlang::UQ(conditions) %>% paste())[2] == "NULL")) {
+
+    valid_nodes <-
+      filter(
+        .data = valid_nodes,
+        rlang::UQ(conditions))
   }
 
   # If the option is taken to copy node attribute
@@ -359,5 +376,5 @@ trav_both <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
