@@ -32,13 +32,15 @@
 #' graph <-
 #'   create_graph() %>%
 #'   add_n_nodes(
-#'     2, type = "a",
+#'     n = 2,
+#'     type = "a",
 #'     label = c("asd", "iekd")) %>%
 #'   add_n_nodes(
-#'     3, type = "b",
+#'     n = 3,
+#'     type = "b",
 #'     label = c("idj", "edl", "ohd")) %>%
 #'   add_edges_w_string(
-#'     "1->2 1->3 2->4 2->5 3->5",
+#'     edges = "1->2 1->3 2->4 2->5 3->5",
 #'     rel = c(NA, "A", "B", "C", "D"))
 #'
 #' # Create a data frame with node ID values
@@ -62,9 +64,10 @@
 #' # edge data frame (edf)
 #' graph <-
 #'   graph %>%
-#'   join_edge_attrs(df_edges) %>%
-#'   join_node_attrs(df_nodes)
+#'   join_edge_attrs(df = df_edges) %>%
+#'   join_node_attrs(df = df_nodes)
 #'
+#' # Show the graph's internal node data frame
 #' get_node_df(graph)
 #' #>   id type label values
 #' #> 1  1    a   asd   8.58
@@ -73,6 +76,7 @@
 #' #> 4  4    b   edl   6.71
 #' #> 5  5    b   ohd   7.48
 #'
+#' # Show the graph's internal edge data frame
 #' get_edge_df(graph)
 #' #>   id from to  rel values
 #' #> 1  1    1  2 <NA>   6.00
@@ -85,7 +89,7 @@
 #' # inward adjacent edges with no conditions
 #' # on the nodes traversed to
 #' graph %>%
-#'   select_nodes_by_id(4) %>%
+#'   select_nodes_by_id(nodes = 4) %>%
 #'   trav_in() %>%
 #'   get_selection()
 #' #> [1] 2
@@ -95,9 +99,9 @@
 #' # numeric values greater than `5.0` for
 #' # the `values` node attribute
 #' graph %>%
-#'   select_nodes_by_id(4) %>%
+#'   select_nodes_by_id(nodes = 4) %>%
 #'   trav_in(
-#'     conditions = "values > 5.0") %>%
+#'     conditions = values > 5.0) %>%
 #'   get_selection()
 #' #> [1] 2
 #'
@@ -105,9 +109,9 @@
 #' # nodes, filtering to those nodes that
 #' # have a `type` attribute of `b`
 #' graph %>%
-#'   select_nodes_by_id(5) %>%
+#'   select_nodes_by_id(nodes = 5) %>%
 #'   trav_in(
-#'     conditions = "type == 'b'") %>%
+#'     conditions = type == "b") %>%
 #'   get_selection()
 #' #> [1] 3
 #'
@@ -121,34 +125,32 @@
 #'     dplyr::select(id, deg)
 #'   join_node_attrs(., node_degrees)
 #'   } %>%
-#'   select_nodes_by_id(5) %>%
+#'   select_nodes_by_id(nodes = 5) %>%
 #'   trav_in(
-#'     conditions = "deg == 2") %>%
+#'     conditions = deg == 2) %>%
 #'   get_selection()
 #' #> [1] 3
 #'
 #' # Traverse from node `5` to any inbound
 #' # nodes, and use multiple conditions for the
-#' # traversal (using a vector in `conditions`
-#' # creates a set of `AND` conditions)
+#' # traversal
 #' graph %>%
-#'   select_nodes_by_id(5) %>%
+#'   select_nodes_by_id(nodes = 5) %>%
 #'   trav_in(
-#'     conditions = c(
-#'       "type == 'a'",
-#'       "values > 6.0")) %>%
+#'     conditions =
+#'       type == "a" &
+#'       values > 6.0) %>%
 #'   get_selection()
 #' #> [1] 2
 #'
 #' # Traverse from node `5` to any inbound
 #' # nodes, and use multiple conditions with
-#' # a single-length vector (here, using a
-#' # `|` to create a set of `OR` conditions)
+#' # a single-length vector
 #' graph %>%
-#'   select_nodes_by_id(5) %>%
+#'   select_nodes_by_id(nodes = 5) %>%
 #'   trav_in(
-#'     conditions = c(
-#'       "type == 'b' | values > 6.0")) %>%
+#'     conditions =
+#'       type == "b" | values > 6.0) %>%
 #'   get_selection()
 #' #> [1] 2 3
 #'
@@ -156,9 +158,9 @@
 #' # nodes, and use a regular expression as
 #' # a filtering condition
 #' graph %>%
-#'   select_nodes_by_id(2) %>%
+#'   select_nodes_by_id(nodes = 2) %>%
 #'   trav_in(
-#'     conditions = "grepl('^i...', label)") %>%
+#'     conditions = grepl("^i.*", label)) %>%
 #'   get_selection()
 #' #> [1] 2
 #'
@@ -169,20 +171,26 @@
 #'   create_graph() %>%
 #'   add_node() %>%
 #'   select_nodes() %>%
-#'   add_n_nodes_ws(2, "from") %>%
+#'   add_n_nodes_ws(
+#'     n = 2,
+#'     direction = "from") %>%
 #'   clear_selection() %>%
-#'   select_nodes_by_id(2:3) %>%
-#'   set_node_attrs_ws("value", 5)
+#'   select_nodes_by_id(nodes = 2:3) %>%
+#'   set_node_attrs_ws(
+#'     node_attr = value,
+#'     value = 5)
 #'
 #' # Show the graph's internal node data frame
-#' graph %>% get_node_df()
+#' graph %>%
+#'   get_node_df()
 #' #>   id type label value
 #' #> 1  1 <NA>  <NA>    NA
 #' #> 2  2 <NA>  <NA>     5
 #' #> 3  3 <NA>  <NA>     5
 #'
 #' # Show the graph's internal edge data frame
-#' graph %>% get_edge_df()
+#' graph %>%
+#'   get_edge_df()
 #' #>   id from to  rel
 #' #> 1  1    1  2 <NA>
 #' #> 2  2    1  3 <NA>
@@ -196,18 +204,20 @@
 #' graph <-
 #'   graph %>%
 #'   trav_in(
-#'     copy_attrs_from = "value",
+#'     copy_attrs_from = value,
 #'     agg = "sum")
 #'
 #' # Show the graph's internal node data frame
 #' # after this change
-#' graph %>% get_node_df()
+#' graph %>%
+#'   get_node_df()
 #' #>   id type label value
 #' #> 1  1 <NA>  <NA>    10
 #' #> 2  2 <NA>  <NA>     5
 #' #> 3  3 <NA>  <NA>     5
-#' @importFrom dplyr filter_ inner_join right_join rename distinct select select_ group_by summarize_ everything
+#' @importFrom dplyr filter inner_join right_join rename distinct select select_ group_by ungroup summarize_ everything
 #' @importFrom tibble as_tibble
+#' @importFrom rlang enquo UQ
 #' @export trav_in
 
 trav_in <- function(graph,
@@ -215,6 +225,15 @@ trav_in <- function(graph,
                     copy_attrs_from = NULL,
                     agg = "sum") {
 
+  conditions <- rlang::enquo(conditions)
+
+  copy_attrs_from <- rlang::enquo(copy_attrs_from)
+  copy_attrs_from <- (rlang::UQ(copy_attrs_from) %>% paste())[2]
+
+  if (copy_attrs_from == "NULL") {
+    copy_attrs_from <- NULL
+  }
+
   # Get the time of function start
   time_function_start <- Sys.time()
 
@@ -275,12 +294,12 @@ trav_in <- function(graph,
   # If traversal conditions are provided then
   # pass in those conditions and filter the
   # data frame of `valid_nodes`
-  if (!is.null(conditions)) {
-    for (i in 1:length(conditions)) {
-      valid_nodes <-
-        valid_nodes %>%
-        dplyr::filter_(conditions[i])
-    }
+  if (!((rlang::UQ(conditions) %>% paste())[2] == "NULL")) {
+
+    valid_nodes <-
+      filter(
+        .data = valid_nodes,
+        rlang::UQ(conditions))
   }
 
   # If the option is taken to copy node attribute
@@ -293,12 +312,23 @@ trav_in <- function(graph,
       dplyr::select(id) %>%
       dplyr::inner_join(edf %>% select(from, to), by = c("id" = "from")) %>%
       dplyr::inner_join(ndf %>% select_("id", copy_attrs_from), by = c("to" = "id")) %>%
-      dplyr::select_("id", copy_attrs_from) %>%
-      dplyr::group_by(id) %>%
-      dplyr::summarize_(.dots = setNames(
-        list(stats::as.formula(
-          paste0("~", agg, "(", copy_attrs_from, ", na.rm = TRUE)"))),
-        copy_attrs_from)) %>%
+      dplyr::select_("id", copy_attrs_from)
+
+    # If the values to be copied are numeric,
+    # perform aggregation on the values
+    if (nodes[, 2] %>% unlist() %>% is.numeric()) {
+      nodes <-
+        nodes %>%
+        dplyr::group_by(id) %>%
+        dplyr::summarize_(.dots = setNames(
+          list(stats::as.formula(
+            paste0("~", agg, "(", copy_attrs_from, ", na.rm = TRUE)"))),
+          copy_attrs_from)) %>%
+        dplyr::ungroup()
+    }
+
+    nodes <-
+      nodes %>%
       dplyr::right_join(ndf, by = "id") %>%
       dplyr::select(id, type, label, dplyr::everything()) %>%
       as.data.frame(stringsAsFactors = FALSE)
@@ -361,5 +391,5 @@ trav_in <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
