@@ -33,46 +33,65 @@ test_that("getting info about a graph's nodes is possible", {
   info_nodes <- node_info(graph)
 
   # Expect a data frame object
-  expect_is(info_nodes, "data.frame")
+  expect_is(
+    info_nodes, "data.frame")
 
   # Expect that the data frame has 7 columns
-  expect_true(ncol(info_nodes) == 7)
+  expect_true(
+    ncol(info_nodes) == 7)
 
   # Expect that the data frame has 26 rows
-  expect_true(nrow(info_nodes) == 26)
+  expect_true(
+    nrow(info_nodes) == 26)
 
   # Expect that certain columns will be classed
   # as `integer` or `character`
-  expect_is(info_nodes$id, "integer")
-  expect_is(info_nodes$label, "character")
-  expect_is(info_nodes$type, "character")
+  expect_is(
+    info_nodes$id, "integer")
+
+  expect_is(
+    info_nodes$label, "character")
+
+  expect_is(
+    info_nodes$type, "character")
 
   # Expect that certain columns will be classed
   # as `numeric`
-  expect_is(info_nodes$deg, "numeric")
-  expect_is(info_nodes$indeg, "numeric")
-  expect_is(info_nodes$outdeg, "numeric")
-  expect_is(info_nodes$loops, "numeric")
+  expect_is(
+    info_nodes$deg, "numeric")
+
+  expect_is(
+    info_nodes$indeg, "numeric")
+
+  expect_is(
+    info_nodes$outdeg, "numeric")
+
+  expect_is(
+    info_nodes$loops, "numeric")
 
   # Create a graph with 4 nodes (with type
   # information) but no edges
-  graph <- create_graph()
-  graph <- add_node(graph, type = "free")
-  graph <- add_node(graph, type = "free")
-  graph <- add_node(graph, type = "free")
-  graph <- add_node(graph, type = "free")
+  graph <-
+    create_graph() %>%
+    add_node(type = "free") %>%
+    add_node(type = "free") %>%
+    add_node(type = "free") %>%
+    add_node(type = "free")
 
   # Get information on nodes that have no edges
   info_nodes_no_edges <- node_info(graph)
 
   # Expect a data frame object
-  expect_is(info_nodes_no_edges, "data.frame")
+  expect_is(
+    info_nodes_no_edges, "data.frame")
 
   # Expect that the data frame has 7 columns
-  expect_true(ncol(info_nodes_no_edges) == 7)
+  expect_true(
+    ncol(info_nodes_no_edges) == 7)
 
   # Expect that the data frame has 4 rows
-  expect_true(nrow(info_nodes_no_edges) == 4)
+  expect_true(
+    nrow(info_nodes_no_edges) == 4)
 
   # Create an empty graph
   graph <- create_graph()
@@ -81,7 +100,8 @@ test_that("getting info about a graph's nodes is possible", {
   info_nodes_empty_graph <- node_info(graph)
 
   # Expect a NULL value
-  expect_null(info_nodes_empty_graph)
+  expect_null(
+    info_nodes_empty_graph)
 })
 
 test_that("getting info about a graph's edges is possible", {
@@ -117,30 +137,40 @@ test_that("getting info about a graph's edges is possible", {
   info_edges <- edge_info(graph)
 
   # Expect a data frame object
-  expect_is(info_edges, "data.frame")
+  expect_is(
+    info_edges, "data.frame")
 
   # Expect that the data frame has 4 columns
-  expect_true(ncol(info_edges) == 4)
+  expect_true(
+    ncol(info_edges) == 4)
 
   # Expect that the data frame has 26 rows
-  expect_true(nrow(info_edges) == 26)
+  expect_true(
+    nrow(info_edges) == 26)
 
   # Expect that all columns will be classed
   # as `character`
-  expect_is(info_edges$from, "integer")
-  expect_is(info_edges$to, "integer")
-  expect_is(info_edges$rel, "character")
+  expect_is(
+    info_edges$from, "integer")
+
+  expect_is(
+    info_edges$to, "integer")
+
+  expect_is(
+    info_edges$rel, "character")
 
   # Create a graph with 4 nodes but no edges
-  graph <- create_graph()
-  graph <- add_node(graph)
-  graph <- add_node(graph)
-  graph <- add_node(graph)
-  graph <- add_node(graph)
+  graph <-
+    create_graph() %>%
+    add_node() %>%
+    add_node() %>%
+    add_node() %>%
+    add_node()
 
   # Get information on a graph that has no edges
   info_graph_no_edges <- edge_info(graph)
 
   # Expect an NA value
-  expect_true(is.na(info_graph_no_edges))
+  expect_true(
+    is.na(info_graph_no_edges))
 })
