@@ -12,7 +12,7 @@ test_that("rescaling node attributes in a graph is possible", {
   # its values are rescaled between 0 and 1
   graph_r_value_0_1 <-
     graph %>%
-    rescale_node_attrs(node_attr_from = "value")
+    rescale_node_attrs(node_attr_from = value)
 
   # Expect that certain (rescaled) values are now
   # available in the graph's ndf
@@ -26,15 +26,15 @@ test_that("rescaling node attributes in a graph is possible", {
   graph_r_value_fill_font_color <-
     graph %>%
     rescale_node_attrs(
-      node_attr_from = "value",
+      node_attr_from = value,
       to_lower_bound = "gray80",
       to_upper_bound = "gray20",
-      node_attr_to = "fillcolor") %>%
+      node_attr_to = fillcolor) %>%
     rescale_node_attrs(
-      node_attr_from = "value",
+      node_attr_from = value,
       to_lower_bound = "gray5",
       to_upper_bound = "gray95",
-      node_attr_to = "fontcolor")
+      node_attr_to = fontcolor)
 
   # Expect that the `fillcolor` and `fontcolor` node
   # attribute columns are now available
@@ -56,7 +56,7 @@ test_that("rescaling node attributes in a graph is possible", {
   # Expect an error if using supplying a node attribute
   # that doesn't exist (`values` instead of `value`)
   expect_error(
-    graph %>% rescale_node_attrs("values"))
+    graph %>% rescale_node_attrs(node_attr_from = values))
 })
 
 test_that("rescaling edge attributes in a graph is possible", {
@@ -67,14 +67,15 @@ test_that("rescaling edge attributes in a graph is possible", {
       n = 5, m = 7,
       set_seed = 23) %>%
     set_edge_attrs(
-      edge_attr = "weight",
+      edge_attr = weight,
       values = rnorm(edge_count(.), 5))
 
   # Rescale the `weight` edge attribute, so that
   # its values are rescaled between 0 and 1
   graph_r_value_0_1 <-
     graph %>%
-    rescale_edge_attrs(edge_attr_from = "weight")
+    rescale_edge_attrs(
+      edge_attr_from = weight)
 
   # Expect that certain (rescaled) values are now
   # available in the graph's edf
@@ -88,15 +89,15 @@ test_that("rescaling edge attributes in a graph is possible", {
   graph_r_value_fill_font_color <-
     graph %>%
     rescale_edge_attrs(
-      edge_attr_from = "weight",
+      edge_attr_from = weight,
       to_lower_bound = "gray80",
       to_upper_bound = "gray20",
-      edge_attr_to = "fillcolor") %>%
+      edge_attr_to = fillcolor) %>%
     rescale_edge_attrs(
-      edge_attr_from = "weight",
+      edge_attr_from = weight,
       to_lower_bound = "gray5",
       to_upper_bound = "gray95",
-      edge_attr_to = "fontcolor")
+      edge_attr_to = fontcolor)
 
   # Expect that the `fillcolor` and `fontcolor` node
   # attribute columns are now available
@@ -121,5 +122,6 @@ test_that("rescaling edge attributes in a graph is possible", {
   # that doesn't exist (`weights` instead of `weight`)
   expect_error(
     graph %>%
-      rescale_edge_attrs(edge_attr_from = "weights"))
+      rescale_edge_attrs(
+        edge_attr_from = weights))
 })
